@@ -127,6 +127,41 @@
 #define DT2821_XCLK	0x0002	/* (R/W) external clock enable            */
 #define DT2821_BDINIT	0x0001	/* (W)   initialize board         */
 
+/*
+--BEGIN-RANGE-DEFS--
+RANGE_dt282x_ai_lo_bipolar
+        -10     10
+        -5      5
+        -2.5    2.5
+        -1.25   1.25
+RANGE_dt282x_ai_lo_bipolar
+        0       10
+        0       5
+        0       2.5
+        0       1.25
+RANGE_dt282x_ai_5_bipolar
+       -5      5
+       -2.5    2.5
+       -1.25   1.25
+       -0.625  0.625
+RANGE_dt282x_ai_5_unipolar
+        0       5
+        0       2.5
+        0       1.25
+        0       0.625
+RANGE_dt282x_ai_hi_bipolar
+        -10     10
+        -1      1
+        -0.1    0.1
+        -0.02   0.02
+RANGE_dt282x_ai_hi_unipolar
+        0       10
+        0       1
+        0       0.1
+        0       0.02
+---END-RANGE-DEFS---
+*/
+
 
 /*
  *    map of boardnames and single ended/differential jumper
@@ -138,6 +173,8 @@ typedef struct {
 	int boardcode_di;
 	int t0, t1, t2;
 } boardname_t;
+
+
 static boardname_t boardnames[] =
 {
 	{"dt2821", 0, 1, RANGE_dt282x_ai_lo_unipolar, RANGE_dt282x_ai_lo_bipolar, 0},
