@@ -54,7 +54,6 @@ static int do_unlock_ioctl(comedi_device *dev,unsigned int arg,void * file);
 static int do_cancel_ioctl(comedi_device *dev,unsigned int arg,void *file);
 
 static void postconfig(comedi_device *dev);
-static int check_chanlist(comedi_subdevice *s,int n,unsigned int *chanlist);
 static void do_become_nonbusy(comedi_device *dev,comedi_subdevice *s);
 
 static int comedi_ioctl(struct inode * inode,struct file * file,unsigned int cmd,unsigned long arg)
@@ -72,6 +71,8 @@ static int comedi_ioctl(struct inode * inode,struct file * file,unsigned int cmd
 		return do_subdinfo_ioctl(dev,(void *)arg,file);
 	case COMEDI_CHANINFO:
 		return do_chaninfo_ioctl(dev,(void *)arg);
+	case COMEDI_RANGEINFO:
+		return do_rangeinfo_ioctl(dev,(void *)arg);
 	case COMEDI_TRIG:
 		return do_trig_ioctl(dev,(void *)arg,file);
 	case COMEDI_LOCK:
@@ -342,9 +343,7 @@ static int do_trig_ioctl(comedi_device *dev,void *arg,void *file)
 
 	/* make sure channel/gain list isn't too long */
 	if(user_trig.n_chan > s->len_chanlist){
-#ifdef DEBUG
-printk("channel/gain list too long %d > %d\n",user_trig.n_chan,s->len_chanlist);
-#endif
+		DPRINTK("channel/gain list too long %d > %d\n",user_trig.n_chan,s->len_chanlist);
 		ret = -EINVAL;
 		goto cleanup;
 	}
@@ -355,8 +354,6 @@ printk("channel/gain list too long %d > %d\n",user_trig.n_chan,s->len_chanlist);
 	s->cur_trig.data=NULL;
 
 	/* load channel/gain list */
-	/* driver is responsible for freeing chanlist, unless it
-	   returns an error */
 	s->cur_trig.chanlist=kmalloc(s->cur_trig.n_chan*sizeof(int),GFP_KERNEL);
 	if(!s->cur_trig.chanlist){
 		ret = -ENOMEM;
@@ -373,11 +370,13 @@ printk("channel/gain list too long %d > %d\n",user_trig.n_chan,s->len_chanlist);
 		goto cleanup;
 	
 	/* allocate buffer */
-	bufsz=s->cur_trig.n*s->cur_trig.n_chan*sizeof(sampl_t);
+	if(s->flags&SDF_LSAMPL){
+		bufsz=s->cur_trig.n*s->cur_trig.n_chan*sizeof(lsampl_t);
+	}else{
+		bufsz=s->cur_trig.n*s->cur_trig.n_chan*sizeof(sampl_t);
+	}
 	if(bufsz>s->maxbufsz){
-#ifdef DEBUG
-printk("buffer size too big %d > %d\n",bufsz,s->maxbufsz);
-#endif
+		DPRINTK("buffer size too big %d > %d\n",bufsz,s->maxbufsz);
 		/* XXX we *should* be able to handle this */
 		ret=-EINVAL;
 		goto cleanup;
@@ -413,9 +412,7 @@ memset(s->cur_trig.data,0xef,bufsz);
 	}
 
 	if(s->cur_trig.mode>=5 || s->trig[s->cur_trig.mode]==NULL){
-#ifdef DEBUG
-printk("bad mode %d\n",s->cur_trig.mode);
-#endif
+		DPRINTK("bad mode %d\n",s->cur_trig.mode);
 		ret=-EINVAL;
 		goto cleanup;
 	}
@@ -431,7 +428,11 @@ printk("bad mode %d\n",s->cur_trig.mode);
 
 	if(ret<0)goto cleanup;
 
-	i=ret*sizeof(sampl_t);
+	if(s->flags&SDF_LSAMPL){
+		i=ret*sizeof(lsampl_t);
+	}else{
+		i=ret*sizeof(sampl_t);
+	}
 	if(i>bufsz){
 		printk("comedi: (bug) trig returned too many samples\n");
 		i=bufsz;
@@ -560,7 +561,6 @@ static int do_cancel(comedi_device *dev,comedi_subdevice *s);
 static int do_cancel_ioctl(comedi_device *dev,unsigned int arg,void *file)
 {
 	comedi_subdevice *s;
-	int ret;
 	
 	if(arg>=dev->n_subdevices)
 		return -EINVAL;
@@ -668,15 +668,21 @@ static ssize_t comedi_read_v22(struct file * file,char *buf,size_t nbytes,loff_t
 	comedi_subdevice *s;
 	int n,m,count=0,retval=0;
 	struct wait_queue wait={current,NULL};
-
-	if(nbytes%sizeof(sampl_t))
-		nbytes-=nbytes%sizeof(sampl_t);
-
-	if(!nbytes)return 0;
+	int sample_size;
 
 	dev=comedi_devices+minor_of_file(file);
 	s=dev->subdevices+file->f_pos;
 
+	if(s->flags&SDF_LSAMPL){
+		sample_size=sizeof(lsampl_t);
+	}else{
+		sample_size=sizeof(sampl_t);
+	}
+	if(nbytes%sample_size)
+		nbytes-=nbytes%sample_size;
+
+	if(!nbytes)return 0;
+
 	if(!s->busy)
 		return 0;
 
@@ -692,7 +698,7 @@ static ssize_t comedi_read_v22(struct file * file,char *buf,size_t nbytes,loff_t
 
 		n=nbytes;
 
-		m=(s->buf_int_ptr-s->buf_user_ptr)*sizeof(sampl_t);
+		m=(s->buf_int_ptr-s->buf_user_ptr)*sample_size;
 		if(m<n)n=m;
 
 		if(n==0){
@@ -717,7 +723,7 @@ static ssize_t comedi_read_v22(struct file * file,char *buf,size_t nbytes,loff_t
 		
 		count+=n;
 		nbytes-=n;
-		s->buf_user_ptr+=n/sizeof(sampl_t);
+		s->buf_user_ptr+=n/sample_size;
 
 		if(s->buf_user_ptr>=s->buf_len){
 			if(s->subdev_flags & SDF_RUNNING)
@@ -942,9 +948,7 @@ void comedi_error(comedi_device *dev,const char *s)
 
 void comedi_done(comedi_device *dev,comedi_subdevice *s)
 {
-#ifdef DEBUG
-printk("comedi_done\n");
-#endif
+	DPRINTK("comedi_done\n");
 
 	if(!(s->cur_trig.flags&TRIG_RT))
 		wake_up_interruptible(&dev->wait);
@@ -957,16 +961,22 @@ printk("comedi_done\n");
 /*
    this function should be called by your interrupt routine
    at end-of-scan events
-
-   this function should be inline, and probably also hand-optimized.
  */
 void comedi_eos(comedi_device *dev,comedi_subdevice *s)
 {
 	if(!(s->cur_trig.flags&TRIG_RT)){
 		if((s->cur_trig.flags&TRIG_WAKE_EOS))
 			wake_up_interruptible(&dev->wait);
-	}else if(s->end_of_scan)
-		s->end_of_scan(s->eos_arg);
+	}else if(s->end_of_scan){
+		int ret;
+
+		ret=s->end_of_scan(s->eos_arg);
+		if(ret){
+			/* this is a little hack */
+			s->buf_int_ptr=0;
+			s->cur_chan=0;
+		}
+	}
 }
 
 static void postconfig(comedi_device *dev)
@@ -992,37 +1002,3 @@ static void postconfig(comedi_device *dev)
 
 }
 
-static int check_chanlist(comedi_subdevice *s,int n,unsigned int *chanlist)
-{
-	int i;
-	int chan;
-
-	/* make sure each element in channel/gain list is valid */
-
-	if(s->range_type){
-		for(i=0;i<n;i++)
-		   	if(CR_CHAN(chanlist[i])>=s->n_chan || 
-			   CR_RANGE(chanlist[i])>=RANGE_LENGTH(s->range_type)){
-#ifdef DEBUG
-printk("bad chanlist[%d]=0x%08x\n",i,chanlist[i]);
-for(i=0;i<n;i++){
-	printk("[%d]=0x%08x\n",i,chanlist[i]);
-}
-#endif
-				return -EINVAL;
-			}
-	}else if(s->range_type_list){
-		for(i=0;i<n;i++){
-			chan=CR_CHAN(chanlist[i]);
-			if(chan>=s->n_chan ||
-			   CR_RANGE(chanlist[i])>=RANGE_LENGTH(s->range_type_list[chan]))
-			   	return -EINVAL;
-		}
-	}else{
-		printk("comedi: (bug) no range type list!\n");
-		return -EINVAL;
-	}
-	return 0;
-}
-
-
