@@ -53,7 +53,6 @@
 
 #include <8255.h>
 
-#define static
 
 /* reference: ground, common, differential, other */
 static int ni_modebits1[4]={ 0x3000, 0x2000, 0x1000, 0 };
@@ -71,6 +70,60 @@ static int ni_range_lkup[]={
 	RANGE_ni_E_ai_limited14
 };
 
+/*
+--BEGIN-RANGE-DEFS--
+RANGE_ni_E_ai
+        -10     10
+        -5      5
+        -2.5    2.5
+        -1      1
+        -0.5    0.5
+        -0.25   0.25
+        -0.1    0.1
+        -0.05   0.05
+        0       20
+        0       10
+        0       5
+        0       2
+        0       1
+        0       0.5
+        0       0.2
+        0       0.1
+RANGE_ni_E_ai_limited
+	-5	5
+	-2.5	2.5
+	-0.5	0.5
+	-0.05	0.05
+	0	10
+	0	5
+	0	1
+	0	0.1
+RANGE_ni_E_ai_limited14
+        -5      5
+        -2.5    2.5
+        -1      1
+        -0.5    0.5
+        -0.25   0.25
+        -0.1    0.1
+        -0.05   0.05
+        0       10
+        0       5
+        0       2
+        0       1
+        0       0.5
+        0       0.2
+        0       0.1
+RANGE_ni_E_ao
+        -10     10
+        0       10
+RANGE_ni_E_ao_ext
+        -10     10
+        0       10
+        -1      1       ext
+        0       1       ext
+---END-RANGE-DEFS---
+*/
+
 
 
 static int ni_dio(comedi_device *dev,comedi_subdevice *s,comedi_trig *it);
@@ -319,7 +372,7 @@ static int ni_ai_mode0(comedi_device *dev,comedi_subdevice *s,comedi_trig *it)
 	/* this function needs to be fixed for multiple channels */
 	ni_load_channelgain_list(dev,it->n_chan,it->chanlist);
 #else
-	ni_load_channelgain_list(dev,it->n_chan,it->chanlist);
+	ni_load_channelgain_list(dev,1,it->chanlist);
 #endif
 
 #if 0
@@ -483,6 +536,7 @@ static void ni_load_channelgain_list(comedi_device *dev,unsigned int n_chan,unsi
 
 		lo=((i==n_chan-1)?0x8000:0) | ((range&0x8)<<5) | (range&0x7);
 		ni_writew(lo,Configuration_Memory_Low);
+DPRINTK("%x %x\n",hi,lo);
 	}
 
 	/* prime the channel/gain list */
@@ -923,10 +977,7 @@ static int ni_E_init(comedi_device *dev,comedi_devconfig *it)
 
 	s=dev->subdevices+0;
 	s->type=COMEDI_SUBD_AI;
-	s->subdev_flags=SDF_READABLE|SDF_GROUND|SDF_COMMON|SDF_DIFF|SDF_OTHER;
-#ifdef CONFIG_COMEDI_RT
-	s->subdev_flags|=SDF_RT;
-#endif
+	s->subdev_flags=SDF_READABLE|SDF_RT|SDF_GROUND|SDF_COMMON|SDF_DIFF|SDF_OTHER;
 #if 0
 	s->subdev_flags|=SDF_DITHER;
 #endif
